From: Marius Gavrilescu <marius@ieval.ro>
Date: Tue, 11 Jun 2019 13:05:53 +0000 (+0300)
Subject: Bump version and update Changes
X-Git-Tag: 0.004_002^0
X-Git-Url: http://git.ieval.ro/?a=commitdiff_plain;h=HEAD;p=io-compress-brotli.git

Bump version and update Changes
---

diff --git a/Changes b/Changes
index c400087..6d35607 100644
--- a/Changes
+++ b/Changes
@@ -1,5 +1,12 @@
 Revision history for Perl extension IO::Compress::Brotli.
 
+0.004_002 2019-06-11T16:06+03:00
+ - Make unbro not require maximum buffer size (RT #129480)
+ - Add "binmode FH" to 01-uncompress.t (RT #125995)
+ - Fix link in POD
+ - Update POD for bro to include configurables (thanks, Mark Zabaro)
+ - Update included Brotli library to v1.0.7
+
 0.004001 2018-05-19T19:58+01:00
  - Update included Brotli library to v1.0.4
  - Use File::Slurper instead of File::Slurp
diff --git a/README b/README
index 1c2da72..e597f3d 100644
--- a/README
+++ b/README
@@ -1,5 +1,5 @@
-IO-Compress-Brotli version 0.004001
-===================================
+IO-Compress-Brotli version 0.004_002
+====================================
 
 Brotli is a data compression format primarily used in web fonts and
 (more recently) HTTP compression.
diff --git a/lib/IO/Compress/Brotli.pm b/lib/IO/Compress/Brotli.pm
index ed206a9..80a7b70 100644
--- a/lib/IO/Compress/Brotli.pm
+++ b/lib/IO/Compress/Brotli.pm
@@ -12,7 +12,7 @@ use IO::Uncompress::Brotli;
 our @EXPORT = qw/bro/;
 our @EXPORT_OK = @EXPORT;
 
-our $VERSION = '0.004001';
+our $VERSION = '0.004_002';
 
 my %BROTLI_ENCODER_MODE = ( generic => 0, text => 1, font => 2 );
 sub mode {
diff --git a/lib/IO/Uncompress/Brotli.pm b/lib/IO/Uncompress/Brotli.pm
index 0cc22e2..f472ca9 100644
--- a/lib/IO/Uncompress/Brotli.pm
+++ b/lib/IO/Uncompress/Brotli.pm
@@ -8,13 +8,13 @@ use parent qw/Exporter/;
 our @EXPORT = qw/unbro/;
 our @EXPORT_OK = @EXPORT;
 
-our $VERSION = '0.004001';
+our $VERSION = '0.004_002';
 
 require XSLoader;
 XSLoader::load('IO::Compress::Brotli', $VERSION);
 
 # 0.004 has unbro with prototype $$
 # 0.004_001 renames it to unbro_given_size, and provides unbro with
 #           prototype $;$ which calls:
 #           * unbro_given_size when called with two arguments
 #           * the OO interface when called with one argument
@@ -73,7 +73,7 @@ data. It allocates a buffer of size I<$maximum_decoded_size> to store
 the decompressed data, if this is not sufficient (or there is another
 error) this function will croak.
 
-As of version 0.004_001, the I<$maximum_decoded_size> argument is
+As of version 0.004_002, the I<$maximum_decoded_size> argument is
 optional. If not provided, B<unbro> uses the streaming interface
 described in the next section to decompress the buffer in blocks of
 one megabyte. The decompressed blocks are concatenated and returned.
@@ -8,13 +8,13 @@ use parent qw/Exporter/;
 XSLoader::load('IO::Compress::Brotli', $VERSION);
 
-# 0.004 has unbro with prototype $$
-# 0.004_001 renames it to unbro_given_size, and provides unbro with
+# 0.004001 has unbro with prototype $$
+# 0.004_002 renames it to unbro_given_size, and provides unbro with
 #           prototype $;$ which calls:
 #           * unbro_given_size when called with two arguments